<?php

namespace Chinkei\Tm\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Chinkei\Tm\Http\Requests\131414Request;
use Chinkei\Tm\Models\131414;

/**
 * Admin web controller class.
 */
class 131414WorkflowController extends BaseController
{

    /**
     * Workflow controller function for 131414.
     *
     * @param Model   $131414
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(131414Request $request, 131414 $131414, $step)
    {

        try {

            $131414->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('tm::131414.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/131414/131414/' . $131414->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/131414/131414/' . $131414->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for 131414.
     *
     * @param Model   $131414
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(131414 $131414, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $131414->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('tm::131414.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('tm::admin.131414.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('tm::admin.131414.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('tm::admin.131414.message', $data)->render();

        }

    }
}
