<?php

namespace Chinkei\Tm\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Chinkei\Tm\Http\Requests\TmRequest;
use Chinkei\Tm\Models\Tm;

/**
 * Admin web controller class.
 */
class TmWorkflowController extends BaseController
{

    /**
     * Workflow controller function for tm.
     *
     * @param Model   $tm
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(TmRequest $request, Tm $tm, $step)
    {

        try {

            $tm->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('tm::tm.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/tm/tm/' . $tm->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/tm/tm/' . $tm->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for tm.
     *
     * @param Model   $tm
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Tm $tm, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $tm->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('tm::tm.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('tm::admin.tm.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('tm::admin.tm.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('tm::admin.tm.message', $data)->render();

        }

    }
}
