<?php

namespace Chinkei\Tm\Policies;

use Litepie\User\Contracts\UserPolicy;
use Chinkei\Tm\Models\Tm;

class TmPolicy
{

    /**
     * Determine if the given user can view the tm.
     *
     * @param UserPolicy $user
     * @param Tm $tm
     *
     * @return bool
     */
    public function view(UserPolicy $user, Tm $tm)
    {
        if ($user->canDo('tm.tm.view') && $user->isAdmin()) {
            return true;
        }

        return $tm->user_id == user_id() && $tm->user_type == user_type();
    }

    /**
     * Determine if the given user can create a tm.
     *
     * @param UserPolicy $user
     * @param Tm $tm
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('tm.tm.create');
    }

    /**
     * Determine if the given user can update the given tm.
     *
     * @param UserPolicy $user
     * @param Tm $tm
     *
     * @return bool
     */
    public function update(UserPolicy $user, Tm $tm)
    {
        if ($user->canDo('tm.tm.edit') && $user->isAdmin()) {
            return true;
        }

        return $tm->user_id == user_id() && $tm->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given tm.
     *
     * @param UserPolicy $user
     * @param Tm $tm
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Tm $tm)
    {
        return $tm->user_id == user_id() && $tm->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given tm.
     *
     * @param UserPolicy $user
     * @param Tm $tm
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Tm $tm)
    {
        if ($user->canDo('tm.tm.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given tm.
     *
     * @param UserPolicy $user
     * @param Tm $tm
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Tm $tm)
    {
        if ($user->canDo('tm.tm.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
