<?php

namespace Chinkei\Tm\Providers;

use Illuminate\Support\ServiceProvider;

class TmServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'tm');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'tm');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('chinkei.tm', function ($app) {
            return $this->app->make('Chinkei\Tm\Tm');
        });

        // Bind Tm to repository
        $this->app->bind(
            'Chinkei\Tm\Interfaces\TmRepositoryInterface',
            \Chinkei\Tm\Repositories\Eloquent\TmRepository::class
        );        // Bind 131414 to repository
        $this->app->bind(
            'Chinkei\Tm\Interfaces\131414RepositoryInterface',
            \Chinkei\Tm\Repositories\Eloquent\131414Repository::class
        );

        $this->app->register(\Chinkei\Tm\Providers\AuthServiceProvider::class);
                $this->app->register(\Chinkei\Tm\Providers\EventServiceProvider::class);
        
        $this->app->register(\Chinkei\Tm\Providers\RouteServiceProvider::class);
                $this->app->register(\Chinkei\Tm\Providers\WorkflowServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['chinkei.tm'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('chinkei/tm.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/tm')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/tm')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
