<?php

namespace Chinkei\Tm\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Chinkei\Tm\Models\Tm;

class TmAction
{
    /**
     * Perform the complete action.
     *
     * @param Tm $tm
     *
     * @return Tm
     */
    public function complete(Tm $tm)
    {
        try {
            $tm->status = 'complete';
            return $tm->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Tm $tm
     *
     * @return Tm
     */public function verify(Tm $tm)
    {
        try {
            $tm->status = 'verify';
            return $tm->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Tm $tm
     *
     * @return Tm
     */public function approve(Tm $tm)
    {
        try {
            $tm->status = 'approve';
            return $tm->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Tm $tm
     *
     * @return Tm
     */public function publish(Tm $tm)
    {
        try {
            $tm->status = 'publish';
            return $tm->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Tm $tm
     *
     * @return Tm
     */
    public function archive(Tm $tm)
    {
        try {
            $tm->status = 'archive';
            return $tm->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Tm $tm
     *
     * @return Tm
     */
    public function unpublish(Tm $tm)
    {
        try {
            $tm->status = 'unpublish';
            return $tm->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
