<?php

namespace Chinkei\Tm\Workflow;

use Chinkei\Tm\Models\Tm;
use Validator;

class TmValidator
{

    /**
     * Determine if the given tm is valid for complete status.
     *
     * @param Tm $tm
     *
     * @return bool / Validator
     */
    public function complete(Tm $tm)
    {
        return Validator::make($tm->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given tm is valid for verify status.
     *
     * @param Tm $tm
     *
     * @return bool / Validator
     */
    public function verify(Tm $tm)
    {
        return Validator::make($tm->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given tm is valid for approve status.
     *
     * @param Tm $tm
     *
     * @return bool / Validator
     */
    public function approve(Tm $tm)
    {
        return Validator::make($tm->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given tm is valid for publish status.
     *
     * @param Tm $tm
     *
     * @return bool / Validator
     */
    public function publish(Tm $tm)
    {
        return Validator::make($tm->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given tm is valid for archive status.
     *
     * @param Tm $tm
     *
     * @return bool / Validator
     */
    public function archive(Tm $tm)
    {
        return Validator::make($tm->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given tm is valid for unpublish status.
     *
     * @param Tm $tm
     *
     * @return bool / Validator
     */
    public function unpublish(Tm $tm)
    {
        return Validator::make($tm->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
